# *Plov*er diction*ary* generation made eas~~y~~ier

See the issues for current TODOs that are planned to be implemented soonishly.

It's up on [PyPI](https://pypi.org/project/plovary/)! You can install it with `pip install plovary`.
